# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][clog], and this project adheres to [Semantic Versioning][semver].

## [Unreleased]

## [0.1.0] - 2021-07-01
### Added
- Allow including python files for settings

[unreleased]: https://github.com/spapanik/dj_settings/compare/v0.1.0...main

[clog]: https://keepachangelog.com/en/1.0.0/
[semver]: https://semver.org/spec/v2.0.0.html
